@@ -12,8 +12,7 @@ from django.contrib.auth.models import User
 from django.db import models
 from django.utils.translation import ugettext as _
 from geocurrency.converters.models import BaseConverter, ConverterResult, \
-    ConverterResultDetail, ConverterResultError, ConverterLoadError, \
-    CalculationResultError, CalculationResultDetail, CalculationResult
+    ConverterResultDetail, ConverterResultError, ConverterLoadError
 from sympy import sympify, SympifyError
 
 from . import UNIT_EXTENDED_DEFINITION, DIMENSIONS, UNIT_SYSTEM_BASE_AND_DERIVED_UNITS, \
@@ -374,11 +373,14 @@ class Dimension:
             logging.warning(f"unable to find base unit for"
                             f"unit system {self.unit_system.system_name}"
                             f" and dimension {self.code}")
-        unit_list.extend(
-            [
-                Unit(unit_system=self.unit_system, pint_unit=unit)
-                for unit in self.unit_system.ureg.get_compatible_units(self.code)
-            ])
+        try:
+            unit_list.extend(
+                [
+                    Unit(unit_system=self.unit_system, pint_unit=unit)
+                    for unit in self.unit_system.ureg.get_compatible_units(self.code)
+                ])
+        except KeyError as e:
+            logging.warning(f"Cannot find compatible units for this dimension {self.code}")
         unit_names = [str(u) for u in unit_list]
         for unit, prefixes in prefixed_units_display.items():
             if unit in unit_names:
@@ -915,6 +917,87 @@ class CalculationPayload:
         self.eob = eob
 
 
+class CalculationResultDetail:
+    """
+    Details of an evaluation
+    """
+    expression = None
+    operands = None
+    magnitude = None
+    unit = None
+
+    def __init__(self, expression: str, operands: [], magnitude: float, unit: str):
+        """
+        Initialize detail
+        :param expression: Expression in the form of a string e.g.: 3*{a} + 2 * {b}
+        :param operands: List of Operands
+        :param magnitude: result of the calculation
+        :param units: dimension of the result
+        """
+        self.expression = expression
+        self.operands = operands
+        self.magnitude = magnitude
+        self.unit = unit
+
+
+class CalculationResultError:
+    """
+    Error details of a wrong calculation
+    """
+    expression = None
+    operands = None
+    date = None
+    error = None
+
+    def __init__(self, expression: str, operands: [], date: date, error: str):
+        """
+        Initialize error detail
+        :param expression: Expression in the form of a string
+        :param operands: List of Operands
+        :param date: date of the evaluation
+        :param error: Error description
+        """
+        self.expression = expression
+        self.operands = operands
+        self.date = date
+        self.error = error
+
+
+class CalculationResult:
+    """
+    Result of a batch of evaluations
+    """
+    id = None
+    detail = []
+    status = None
+    errors = []
+
+    def __init__(self, id: str = None, detail: [CalculationResultDetail] = None,
+                 status: str = BaseConverter.INITIATED_STATUS,
+                 errors: [CalculationResultError] = None):
+        """
+        Initialize result
+        :param id: ID of the batch
+        :param detail: List of CalculationResultDetail
+        :param status: status of the batch
+        :param errors: List of CalculationResultErrors
+        """
+        self.id = id
+        self.detail = detail or []
+        self.status = status
+        self.errors = errors or []
+
+    def end_batch(self):
+        """
+        Puts a finall status on the batch
+        """
+        if self.errors:
+            self.status = BaseConverter.WITH_ERRORS
+        else:
+            self.status = BaseConverter.FINISHED
+        return self.status
+
+
 class ExpressionCalculator(BaseConverter):
     """
     Conversion between units
