@@ -1,3 +1,7 @@
+"""
+Renderer for Units
+"""
+
 import json
 from rest_framework.renderers import JSONRenderer
 from rest_framework.settings import api_settings
@@ -7,10 +11,13 @@ from .models import Operand
 
 
 class UnitsEncoder(JSONEncoder):
+    """
+    Encoder for Custom Unit
+    """
 
     def default(self, obj):
         if isinstance(obj, Operand):
-            return json.dumps({'name': obj.name, 'value': obj.value, 'unit': obj.value})
+            return json.dumps({'name': obj.name, 'value': obj.value, 'unit': obj.unit})
         else:
             return super().default(obj)
 
